%plotiddata Script to plot identification data.
%   plotiddata plots the identification data used to create
%   our Li-S equivalent circuit network model. Please
%   inspect the code for details.


%%% Initialization

close all
clear

% To keep the code compact, we define a pair of function
% handles here.  We'll use these later on to make plots.
plotCmd = @(theAxes, ThisCell, ThisProp) plot(theAxes, ...
    ThisCell.Deg10.(ThisProp).Time, ThisCell.Deg10.(ThisProp).Data, ...
    ThisCell.Deg20.(ThisProp).Time, ThisCell.Deg20.(ThisProp).Data, ...
    ThisCell.Deg30.(ThisProp).Time, ThisCell.Deg30.(ThisProp).Data, ...
    ThisCell.Deg50.(ThisProp).Time, ThisCell.Deg50.(ThisProp).Data);
legendCmd = @(theAxes)legend(theAxes, ...
    '10 ^oC', '20 ^oC', '30 ^oC', '50 ^oC');


%% Cell 1
%
% First we load the data for each temperature point.  Then we
% plot it.  We use a helper function to improve readability.
%
fileName = 'Cell_1_Mixed_pulse_MACCOR _6_GP1130614-24mixpulse10deg.mat';
Cell{1}.Deg10 = loadDataSet(fileName);

fileName = 'Cell_1_Mixed_pulse_MACCOR _6_GP1130614-24mixpulse20deg.mat';
Cell{1}.Deg20 = loadDataSet(fileName);

fileName = 'Cell_1_Mixed_pulse_MACCOR _6_GP1130614-24mixpulse30deg.mat';
Cell{1}.Deg30 = loadDataSet(fileName);

fileName = 'Cell_1_Mixed_pulse_MACCOR _6_GP1130614-24mixpulse50deg.mat';
Cell{1}.Deg50 = loadDataSet(fileName);


figure(1)
clf
subplot(211)
axes(1) = gca();
subplot(212)
axes(2) = gca();

  
plotCmd(axes(1), Cell{1}, 'Voltage');
legendCmd(axes(1));
xlabel(axes(1), 'Time (hours)')
ylabel(axes(1), 'Load Voltage (volts)');

subplot(212)
plotCmd(axes(2), Cell{1}, 'Current');
legendCmd(axes(1));
xlabel(axes(2), 'Time (hours)')
ylabel(axes(2), 'Load Current (amps)');

title(axes(1), 'Data for Cell 1');
linkaxes(axes, 'x');


%% Cell 2
%
% First we load the data for each temperature point.  Then we
% plot it.  We use a helper function to improve readability.
%
fileName = 'Cell_2_Mixed_pulse_MACCOR _6_GP1130614-15mixpulse10deg.mat';
Cell{2}.Deg10 = loadDataSet(fileName);

fileName = 'Cell_2_Mixed_pulse_MACCOR _6_GP1130614-15mixpulse20deg.mat';
Cell{2}.Deg20 = loadDataSet(fileName);

fileName = 'Cell_2_Mixed_pulse_MACCOR _6_GP1130614-15mixpulse30deg.mat';
Cell{2}.Deg30 = loadDataSet(fileName);

fileName = 'Cell_2_Mixed_pulse_MACCOR _6_GP1130614-15mixpulse50deg.mat';
Cell{2}.Deg50 = loadDataSet(fileName);

figure(2)
clf
subplot(211)
axes(1) = gca();
subplot(212)
axes(2) = gca();

  
plotCmd(axes(1), Cell{2}, 'Voltage');
legendCmd(axes(1));
xlabel(axes(1), 'Time (hours)')
ylabel(axes(1), 'Load Voltage (volts)');

subplot(212)
plotCmd(axes(2), Cell{2}, 'Current');
legendCmd(axes(1));
xlabel(axes(2), 'Time (hours)')
ylabel(axes(2), 'Load Current (amps)');

title(axes(1), 'Data for Cell 2');
linkaxes(axes, 'x');


%% Clean-Up

clear axes fileName
clear plotCmd legendCmd
